@@ -17,3 +17,11 @@ test_that("list_vocabularies", {
 test_that("list_vocabularies", {
   expect_error(svc$list_vocabularies(MaxResults = 20), NA)
 })
+
+test_that("list_vocabulary_filters", {
+  expect_error(svc$list_vocabulary_filters(), NA)
+})
+
+test_that("list_vocabulary_filters", {
+  expect_error(svc$list_vocabulary_filters(MaxResults = 20), NA)
+})
